import { createSignal, createEffect, onCleanup } from "solid-js";
import { a as addListener, d as getLineBefore, f as getLineEnd, s as scrollToEl } from "../index-k8FOC6Zh.js";
import { template, insert } from "solid-js/web";
import "../core-7ijP1_R8.js";
import "../index-SjNLqops.js";
const cursorTemplate = template(
  "<div style=position:absolute;top:0;opacity:0;padding:inherit><span><span>"
);
const cursorPosition = () => (editor) => {
  const [before, setBefore] = createSignal("");
  const [after, setAfter] = createSignal("");
  const container = cursorTemplate();
  const span = container.firstChild;
  const cursor = span.firstChild;
  const scrollIntoView = () => scrollToEl(editor, cursor);
  const remove = addListener(editor, "input", (e) => {
    if (/history/.test(e.inputType))
      scrollIntoView();
  });
  insert(container, before, span);
  insert(span, after, null);
  createEffect(() => {
    const selection = editor.selection();
    const value = editor.value;
    const position = selection[selection[2] < "f" ? 0 : 1];
    const newBefore = getLineBefore(value, position);
    const newAfter = value.slice(position, getLineEnd(value, position));
    const activeLine = editor.lines[editor.activeLine];
    setBefore(newBefore);
    setAfter(newBefore || newAfter ? newAfter : "\n");
    if (container.parentNode != activeLine)
      activeLine.prepend(container);
  });
  onCleanup(() => {
    delete editor.extensions.cursor;
    container.remove();
    remove();
  });
  editor.extensions.cursor = {
    scrollIntoView,
    getPosition() {
      const rect1 = cursor.getBoundingClientRect();
      const rect2 = editor.lines[0].getBoundingClientRect();
      return {
        top: rect1.y - rect2.y,
        bottom: rect2.bottom - rect1.bottom,
        left: rect1.x - rect2.x,
        right: rect2.right - rect1.x,
        height: rect1.height
      };
    }
  };
};
export {
  cursorPosition
};
//# sourceMappingURL=cursor.js.map
